==> hs-QuickCheck-2.5.1.1p0.tgz: lib/ghc/QuickCheck-2.5.1.1/register.sh <==
#!/bin/sh
echo 'name: QuickCheck
version: 2.5.1.1
id: QuickCheck-2.5.1.1-4a9242f1b61a140fe486a54f5467ba42

license: BSD3
copyright: 2000-2012 Koen Claessen, 2006-2008 Björn Bringert, 2009-2012 Nick Smallbone
maintainer: QuickCheck developers <quickcheck@projects.haskell.org>
stability:
homepage: http://code.haskell.org/QuickCheck
package-url:
synopsis: Automatic testing of Haskell programs
description: QuickCheck is a library for random testing of program properties.
             .
             The programmer provides a specification of the program, in
             the form of properties which functions should satisfy, and
             QuickCheck then tests that the properties hold in a large number
             of randomly generated cases.
             .
             Specifications are expressed in
             Haskell, using combinators defined in the QuickCheck library.
             QuickCheck provides combinators to define properties, observe
             the distribution of test data, and define test
             data generators.
category: Testing
author: Koen Claessen <koen@chalmers.se>
pkgpath: devel/hs-QuickCheck
exposed: True
exposed-modules: Test.QuickCheck.All Test.QuickCheck.Function
                 Test.QuickCheck Test.QuickCheck.Arbitrary Test.QuickCheck.Gen
                 Test.QuickCheck.Monadic Test.QuickCheck.Modifiers
                 Test.QuickCheck.Property Test.QuickCheck.Test Test.QuickCheck.Text
                 Test.QuickCheck.Poly Test.QuickCheck.State
hidden-modules: Test.QuickCheck.Exception
trusted: False
import-dirs: /usr/local/lib/ghc/QuickCheck-2.5.1.1
library-dirs: /usr/local/lib/ghc/QuickCheck-2.5.1.1
hs-libraries: HSQuickCheck-2.5.1.1
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
         random-1.0.1.1-d8f82f84701874725b418c29860a58e0
         template-haskell-2.7.0.0-826c08e99d445bf7fa4a34d70f491207
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-QuickCheck-2.5.1.1/html/QuickCheck.haddock
haddock-html: /usr/local/share/doc/hs-QuickCheck-2.5.1.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-QuickCheck-2.6.tgz: lib/ghc/QuickCheck-2.6/register.sh <==
#!/bin/sh
echo 'name: QuickCheck
version: 2.6
id: QuickCheck-2.6-b2c516c95dc721ca4b3874375f2395ba

license: BSD3
copyright: 2000-2012 Koen Claessen, 2006-2008 Björn Bringert, 2009-2012 Nick Smallbone
maintainer: QuickCheck developers <quickcheck@projects.haskell.org>
stability:
homepage: http://code.haskell.org/QuickCheck
package-url:
synopsis: Automatic testing of Haskell programs
description: QuickCheck is a library for random testing of program properties.
             .
             The programmer provides a specification of the program, in
             the form of properties which functions should satisfy, and
             QuickCheck then tests that the properties hold in a large number
             of randomly generated cases.
             .
             Specifications are expressed in
             Haskell, using combinators defined in the QuickCheck library.
             QuickCheck provides combinators to define properties, observe
             the distribution of test data, and define test
             data generators.
category: Testing
author: Koen Claessen <koen@chalmers.se>
pkgpath: devel/hs-QuickCheck
exposed: True
exposed-modules: Test.QuickCheck.All Test.QuickCheck.Function
                 Test.QuickCheck Test.QuickCheck.Arbitrary Test.QuickCheck.Gen
                 Test.QuickCheck.Monadic Test.QuickCheck.Modifiers
                 Test.QuickCheck.Property Test.QuickCheck.Test Test.QuickCheck.Text
                 Test.QuickCheck.Poly Test.QuickCheck.State
hidden-modules: Test.QuickCheck.Exception
trusted: False
import-dirs: /usr/local/lib/ghc/QuickCheck-2.6
library-dirs: /usr/local/lib/ghc/QuickCheck-2.6
hs-libraries: HSQuickCheck-2.6
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.6.0.1-03845c6da2a0b3b4d0d49cc26c0cd3c0
         random-1.0.1.1-023a342365721422ffd5a919bc8708bb
         template-haskell-2.8.0.0-fea87269e8939065140c93e716ec3dfc
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-QuickCheck-2.6/html/QuickCheck.haddock
haddock-html: /usr/local/share/doc/hs-QuickCheck-2.6/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
